==> haskell-cprng-aes-0.6.1-221-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-3upiyimRg5D9KNEMOhCBcw
key:                  cprng-aes-0.6.1-3upiyimRg5D9KNEMOhCBcw
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  0ad2d73aa852e1b81b49e7a1c88f2406
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-3upiyimRg5D9KNEMOhCBcw
depends:
    base-4.15.0.0 byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ
    bytestring-0.10.12.1 cipher-aes-0.2.11-2yZRRjJrigR2ORcvVSVCkF
    crypto-random-0.0.9-Gwan7Mh3W2mB0daFVyUHp

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-222-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-9WJsUwFj0ZoJeZsXrk3RDI
key:                  cprng-aes-0.6.1-9WJsUwFj0ZoJeZsXrk3RDI
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  11239b9e92968c3376a374e4e323e160
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-9WJsUwFj0ZoJeZsXrk3RDI
depends:
    base-4.15.0.0 byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ
    bytestring-0.10.12.1 cipher-aes-0.2.11-2yZRRjJrigR2ORcvVSVCkF
    crypto-random-0.0.9-EgoV8y6wyqY1qYO0TgAM4k

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
